- Incorporates all (applicable) changes from `release 1.9.8 <rel-1.9.8>`:ref:\

- Fix bug__ when comparing version numbers (`xoutil.versions`:mod:).

  __ https://gitlab.merchise.org/merchise/xoutil/merge_requests/12
